netapp_ontap.models.account_application API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.account_application`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AccountApplicationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AccountApplication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `application GET POST PATCH`

    Applications

    Valid choices:

    - console
    - http
    - ontapi
    - service_processor
    - ssh
  `authentication_methods GET POST PATCH`

    The authentication_methods field of the account_application.

  `second_authentication_method GET POST PATCH`

    An optional additional authentication method for MFA. This only works with SSH as the application. It is ignored for all other applications.

    Valid choices:

    - none
    - password
    - publickey
    - nsswitch